<?php
/*
Plugin Name: feedHi for Wordpress
Plugin URI: http://feedhi.com/plugin
Description: Publishing automatically on social networks: Facebook, Twitter, Linkedin, VK. Broadcast your news throught by themed groups. More info at <a href="http://feedhi.com/plugin">http://feedhi.com/plugin/</a>
Version: 1.0
Author: FeedHi Comunicación
Author URI: http://feedhi.com
License: GPL2
*/

function pre($a,$dismiss=false) {
    echo "<pre>";
    print_r($a);
    echo "</pre>";
    if($dismiss) die();
}

function truncate($text,$len) {
    if(strlen($text) <= $len)
        return $text;
    return substr($text, 0, $len).'...';
}

function t($t=false) {
    global $feedhi_langs;
    global $feedhi_current_lang;
    
    if($feedhi_current_lang=='en_US')
        $tmp_lang = 'en_US';
    else if($feedhi_current_lang=='es_ES')
        $tmp_lang = 'es_ES';
    else
        $tmp_lang = 'en_US';
    if(!$t) return '';
    return $feedhi_langs[$t][$tmp_lang];
}

function userNav() {
    $nav_lang = explode(",",$_SERVER["HTTP_ACCEPT_LANGUAGE"]);
    $nav_lang = str_replace("-","_",$nav_lang[0]);
    if(strpos($nav_lang, 'es_')) return 'es_ES';
    else return 'en_US';
}

include(plugin_dir_path( __FILE__ ).'inc/lang.php');

register_activation_hook( __FILE__, array( 'feedHiClass', 'feedhi_install' ) );
register_deactivation_hook( __FILE__, array( 'feedHiClass', 'feedhi_uninstall' ) );
//add_action( 'plugins_loaded', array( 'feedHiClass', 'init' ) );

/** ===================================================
 * Clase para manejar las funcionalidades del plugin
 * =================================================== */
class feedHiClass {

    /**  propiedades de la clase **/
    private $site_url;
    private $api_url;
    public $lang;
    
    /** ===================================================
     * Construye la clase y determina las rutas
     * =================================================== */
    public function feedHiClass() {
        global $feedhi_current_lang;
        
        $this->site_url = plugins_url( '/', __FILE__ );
        $this->api_url = 'http://api.feedhi.com/';
		add_action('admin_menu', array(&$this, '_AddMenu'));

        //Comprobamos si el plugin está habilitado
        $this->feedhi_check();
        
        //Idioma
        $getLang = $this->getLang();
        $feedhi_current_lang = (isset($getLang->errorcode))?userNav():$getLang->lang;
        
        //Ajax
        add_action('wp_ajax_fh_callback', array(&$this,'ajaxCallback'));
    }
	
    /** ===================================================
     * Muestra las opciones de configuración del plugin
     * =================================================== */
    function settingsPage(){
        $fdhi = $this;
        include(plugin_dir_path( __FILE__ ).'inc/ajustes.php');
    }
    
    /** ===================================================
     * función que añade la página ajustes al correspondiente menú de WP
     * =================================================== */
    function _AddMenu() {
        add_menu_page(
			'feedHi 4WP',                // título de la página
			'feedHi 4WP',                // texto del menu
		    'manage_options',            // rol para manejar
			'feedhi-settings',           // slug de la página
			array($this,'settingsPage'), //callback
			plugins_url('img/logo.png',__FILE__)
		);
    }

    public function ajaxCallback() {
        //print_r($_REQUEST);
        if(isset($_POST['mode'])) {
            $mode = $_POST['mode'];
            
            switch($mode) {
                case 'sendblog':
                    $result = $this->sendBlog();
                    break;
                case 'setblog':
                    $data = array(
                        'id' => $_REQUEST['id'],
                        'mode' => $_REQUEST['attr'],
                        'value' => $_REQUEST['val'],
                    );
                    $result = $this->setBlog($data);
                    break;
                case 'grouplist':
                    $data = array(
                        'id' => $_REQUEST['id'],
                    );
                    $result = $this->getGroupList($data);
                    break;
                case 'joingroup':
                    $data = array(
                        'id' => $_REQUEST['id'],
                    );
                    $result = $this->joinGroup($data);
                    break;
                case 'leavegroup':
                    $data = array(
                        'id' => $_REQUEST['id'],
                    );
                    $result = $this->leaveGroup($data);
                    break;
                case 'setpubmode':
                    $data = array(
                        'val' => $_REQUEST['val'],
                    );
                    $result = $this->setPubMode($data);
                    break;
            }
            
            print json_encode($result);
            die();
            wp_die(); // this is required to terminate immediately and return a proper response
        }
    }
    
    public function getUrlSitio() { return $this->site_url; }

    /**
     * Hoja de estilos
     */        
    public function feedHiStylesheet() {
        wp_enqueue_style('feedHi-stylesheet', $this->site_url.'css/styles.css');
    }
    
    /**
     * Variables para scripts
     */
    public function feedhi_my_vars() {
    ?>
    <script type="text/javascript" >
    var blog_url='<?php echo get_site_url();?>';
    var plugin_url='<?php echo $this->site_url;?>';
    var please='<?php echo t('por_favor_grupo');?>';
    </script>
    <?php
    }

    /**
     * Scripts js
     */
    public function feedHiScripts() {
        wp_enqueue_script('feedHi-script',$this->site_url.'js/settings.js',array('jquery'));
    }

    /**
     * Comprobación registro
     */
    private function feedhi_check() {
        $plugins = get_option('active_plugins');
        $required_plugin = 'feedhi-4wp/feedhi-4wp.php';
        if(in_array($required_plugin, $plugins)) {
            if(get_option('feedhi_version')===false || get_option('feedhi_api')===false || get_option('feedhi_token')===false) {
                $data = $this->getCredentials();
                if(get_option('feedhi_version')===false) add_option('feedhi_version','1.1');
                if(get_option('feedhi_api')===false) add_option('feedhi_api',$data['auth']);
                if(get_option('feedhi_token')===false) add_option('feedhi_token',$data['token']);
            }
        }
    }

    /* ===================================================
     * Función de instalación
     * =================================================== */
    public function feedhi_install() {
        if(!current_user_can('activate_plugins'))
            return;

        $data = self::getCredentials();
        
        $opts = array(
            "feedhi_version" => "1.1",
            "feedhi_api" => $data->auth,
            "feedhi_token" => $data->token
        );
        foreach($opts as $i => $v) {
            if(get_option($i)===false) {
                add_option($i,$v);
            } else {
                update_option($i,$v);
            }
        }
    }

    /* ===================================================
     * Función de desinstalación
     * =================================================== */
    public static function feedhi_uninstall() {
        if(!current_user_can('activate_plugins'))
            return;

        delete_option("feedhi_version");
        delete_option("feedhi_user");
        delete_option("feedhi_api");
        delete_option("feedhi_token");
    }
    
    
    /* ===================================================
     * Métodos API
     * =================================================== */
    public function getLang() {
        $params = array(
            'request' => 'get-lang',
            'args' => false
        );
        return json_decode($this->getApiData($params));
    }
    
    public function getProfile() {
        $params = array(
            'request' => 'get-profile',
            'args' => false
        );
        $prof = json_decode($this->getApiData($params));
        if(get_option('feedhi_user')!==false && isset($prof->errorcode) && $prof->errorcode > 0) {
            delete_option("feedhi_user");
        }
        return $prof;
    }
    
    public function getBlogs() {
        $params = array(
            'request' => 'get-blogs',
            'args' => false
        );
        return json_decode($this->getApiData($params));
    }
    
    public function getGroups() {
        $params = array(
            'request' => 'get-groups',
            'args' => false
        );
        return json_decode($this->getApiData($params));
    }
    
    public function getCategories() {
        $params = array(
            'request' => 'category-list',
            'args' => false
        );
        return json_decode($this->getApiData($params));
    }
    
    public function getGroupList($data) {
        $params = array(
            'request' => 'group-list',
            'args' => array(
                'id' => $data['id'],
            )
        );
        return json_decode($this->getApiData($params));
    }
    
    public function sendBlog() {
        $params = array(
            'request' => 'add-blog',
            'args' => array(
                'blog_url' => get_site_url(),
                'blog_name' => get_bloginfo('name'),
                'feed_url' => get_bloginfo('rss_url'),
            )
        );
        return json_decode($this->getApiData($params));
    }
    
    public function setBlog($data) {
        $params = array(
            'request' => 'set-blog',
            'args' => array(
                'id' => $data['id'],
                'mode' => $data['mode'],
                'value' => $data['value'],
            )
        );
        return json_decode($this->getApiData($params));
    }
    
    public function joinGroup($data) {
        $params = array(
            'request' => 'join-group',
            'args' => array('id' => $data['id'])
        );
        return json_decode($this->getApiData($params));
    }
    
    public function leaveGroup($data) {
        $params = array(
            'request' => 'leave-group',
            'args' => array('id' => $data['id'])
        );
        return json_decode($this->getApiData($params));
    }
    
    public function setPubMode($data) {
        $params = array(
            'request' => 'set-pub-mode',
            'args' => array('value' => $data['val'])
        );
        return json_decode($this->getApiData($params));
    }
    
    public function getCredentials() {
        $params = array(
            'url' => 'http://feedhi.com/',
            'method' => 'get',
            'request' => 'get-wordpress-credentials',
            'args' => array('value' => $data['val'])
        );
        return json_decode(self::getApiData($params));
    }
    
    protected function getApiData($data = array()) {
        $args = array(
            'auth_login' => get_option("feedhi_api"),
            'auth_token' => get_option("feedhi_token")
        );
        if(get_option("feedhi_user"))
            $args['auth_user'] = get_option("feedhi_user");
        if(is_array($data['args']) && count($data['args'])>0) foreach($data['args'] as $index => $value)
            $args[$index] = $value;
        $params = array(
            'url' => (isset($data['url'])?$data['url']:$this->api_url).$data['request'],
            'method' => isset($data['method'])?$data['method']:'post',
            'args' => $args
        );
        return self::makeRequest($params);
    }
    
    protected function makeRequest($params=array()){
        $method=isset($params['method'])?$params['method']:'get';
        $headers = isset($params['headers'])?$params['headers']:array();
        $args = isset($params['args'])?$params['args']:'';
        $url = $params['url'];

        $url.='?';
        if($method=='get'){
            $url.='&'.self::preparePostFields($args);
        }
        $ch = curl_init();
        curl_setopt($ch, CURLOPT_URL, $url);
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, TRUE);
        curl_setopt($ch, CURLOPT_HTTPAUTH, CURLAUTH_ANY);
        curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false);
        curl_setopt($ch, CURLOPT_SSL_VERIFYHOST, false);
        if($method=='post'){
            curl_setopt($ch, CURLOPT_POST, TRUE);
            curl_setopt($ch, CURLOPT_POSTFIELDS, self::preparePostFields($args));
        }elseif($method=='delete'){
            curl_setopt($ch, CURLOPT_CUSTOMREQUEST, "DELETE");
        }elseif($method=='put'){
            curl_setopt($ch, CURLOPT_CUSTOMREQUEST, "PUT");
        }
        if(is_array($headers) && !empty($headers)){
            $headers_arr=array();
            foreach($headers as $k=>$v){
                $headers_arr[]=$k.': '.$v;
            }
            curl_setopt($ch,CURLOPT_HTTPHEADER,$headers_arr);
        }
        $result = curl_exec($ch);
        curl_close($ch);
        return $result;
    }

    protected function preparePostFields($array) {
        if(is_array($array)){
            $params = array();
            foreach ($array as $key => $value) {
                $params[] = $key . '=' . urlencode($value);
            }
            return implode('&', $params);
        }else{
            return $array;
        }
    }
}  // fin de la clase

$fdhi = new feedHiClass();

